from allauth.socialaccount import providers
from allauth.socialaccount.providers.base import ProviderAccount
from allauth.socialaccount.providers.oauth2.provider import OAuth2Provider
from allauth.account.models import EmailAddress

class Authentic2Account(ProviderAccount):
    def to_str(self):
        return self.account.uid


class Authentic2Provider(OAuth2Provider):
    id = 'authentic2'
    name = 'Authentic2'
    package = 'portail_citoyen2.allauth_authentic2'
    account_class = Authentic2Account

    def extract_uid(self, data):
        return str(data['username'])

    def extract_common_fields(self, data):
        return dict(email=data.get('email'),
                    username=data.get('username'),
                    name=data.get('displayname'))

    def extract_email_addresses(self, data):
        ret = [EmailAddress(email=data['email'],
                            verified=True,
                            primary=True)]
        return ret



providers.registry.register(Authentic2Provider)
